# Amazon price scraper plugin for changedetection.io

A small scraper to get the price data from Amazon pages which can be used to improve the "restock and price detection" mode in changedetection.io
